@@ -5,8 +5,8 @@ $self = {
                       'Cairo',
                       'Glib'
                     ],
-          'inc' => '-I/usr/include/cairo -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1 -I/usr/include/freetype2 -I/usr/include/libpng16 -I/usr/include/uuid ',
-          'libs' => '-lcairo-gobject -l:libcairo.dll.a -lgobject-2.0 -lglib-2.0 -lintl ',
+          'inc' => '-I/usr/include/cairo -I/usr/include/freetype2 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1 -I/usr/include/uuid -I/usr/include/libpng16',
+          'libs' => '-lcairo-gobject -l:libcairo.dll.a -lgobject-2.0 -lglib-2.0 -lintl',
           'typemaps' => []
         };
 
@@ -27,11 +27,6 @@ $inc = $self->{inc};
 
 	sub Inline {
 		my ($class, $lang) = @_;
-		if ($lang ne 'C') {
-			warn "Warning: Inline hints not available for $lang language
-";
-			return;
-		}
 		+{ map { (uc($_) => $self->{$_}) } qw(inc libs typemaps) };
 	}
 
